@@ -23,6 +23,9 @@ logging_folder = '/tmp/logger/'
 # 设置分片上传过程中的上传记录存储路径
 tmp_record_folder = '/tmp/sliceupload/'
 
+# 设置分片上传并发线程数
+Thread_num = 4
+
 class PutPolicy(object):
     
     def __init__(self):
