@@ -8,6 +8,7 @@ import time
 import requests
 import multiprocessing
 from multiprocessing.dummy import Pool as ThreadPool
+import threading
 
 from wcs.commons.config import PUT_URL
 from wcs.commons.config import _BLOCK_SIZE
@@ -27,7 +28,8 @@ from wcs.commons.util import file_to_stream
 from wcs.commons.util import GetUuid
 from uploadprogressrecorder import UploadProgressRecorder
 
-record_lock = multiprocessing.Lock()
+#record_lock = multiprocessing.Lock()
+record_lock = threading.Lock()
 
 
 
@@ -40,10 +42,7 @@ class SliceUpload(object):
         self.upload_progress_recorder = upload_progress_recorder
         self.modify_time = modify_time
         self.key = key
-        if isinstance(self.filepath, str):
-            self.size = os.path.getsize(self.filepath)
-        if isinstance(self.filepath, file):
-            self.size = os.fstat(self.filepath.fileno()).st_size
+        self.size = os.path.getsize(self.filepath)
         self.params = params
         self.num = self.size/_BLOCK_SIZE + 1
         self.status = []
@@ -119,8 +118,20 @@ class SliceUpload(object):
             self.logger.info('Thare are %d offsets need to upload', len(offsets))
             if uploadBatch == 'Null':
                 uploadBatch = GetUuid()
+                self.progress = 0
+                self.logger.info('current upload progress: %d', self.progress)
+            else:
+                lastblock = self.size - (len(offsets)-1) * _BLOCK_SIZE
+                current = 0
+                currentlist = list(set(self.offsetlist) - set(offsets))
+                for offset in currentlist:
+                    if offset != max(offsets):
+                        current += _BLOCK_SIZE
+                    else:
+                        current += lastblock
+                self.progress = float(current)/float(self.size)
+                self.logger.info('current upload progress: %d', current)
             self.uploadBatch = uploadBatch
-            self.progress = float(self.size - len(offsets) * _BLOCK_SIZE)/float(self.size)
             
             self.logger.info('Now start upload file blocks')
             pool = ThreadPool(Thread_num)
@@ -160,10 +171,7 @@ class SliceUpload(object):
         return url
 
     def make_block(self, offset):
-        if isinstance(self.filepath, str):
-            openfile = file_to_stream(self.filepath)
-        if isinstance(self.filepath, file):
-            openfile = self.filepath
+        openfile = file_to_stream(self.filepath)
         bput = readfile(openfile, offset, _BPUT_SIZE)
         url = self.mlkblock_url(offset)
         headers = self.block_headers(self.uploadBatch)
@@ -197,8 +205,7 @@ class SliceUpload(object):
             offset_next = offset + bputtext['offset']
             bput_next = readfile(inputfile, offset_next, _BPUT_SIZE)
             bputnum += 1
-        if isinstance(self.filepath, str):
-            inputfile.close()
+        inputfile.close()
         return offset, bputcode, bputtext['ctx']
       
     def block_url(self, size, blocknum):
